@@ -13,7 +13,7 @@ import (
 
 	"github.com/golang/glog"
 
-	"github.com/openshift/api/user/v1"
+	v1 "github.com/openshift/api/user/v1"
 	groupclient "github.com/openshift/client-go/user/clientset/versioned"
 )
 
